#
# spec file for package rtorrent
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rtorrent
Version:        0.9.8
Release:        bp155.3.10
Summary:        Console-based BitTorrent Client
License:        SUSE-GPL-2.0+-with-openssl-exception
Group:          Productivity/Networking/File-Sharing
URL:            https://github.com/rakshasa/rtorrent

Source:         https://github.com/rakshasa/rtorrent/releases/download/v%version/%name-%version.tar.gz
Source2:        rtorrent.desktop
# This manpage copied from the 0.9.2 tarball as it was missing in later versions
Source3:        rtorrent.1
Source4:        rtorrent.service
Patch1:         0001-utils-lockfile-avoid-stack-overflow-for-lockfile-buf.patch
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cppunit) >= 1.9.6
BuildRequires:  pkgconfig(libcurl) >= 7.15.4
BuildRequires:  pkgconfig(libtorrent) >= 0.13.8
BuildRequires:  pkgconfig(xmlrpc)
Requires(pre):  shadow

%description
rTorrent is a console-based BitTorrent client. It aims to be a
fully-featured and efficient client with the ability to run in the
background using screen. It supports fast-resume and session
management.

%prep
%autosetup -p1

%build
# It's full of type pun violations
export CFLAGS="%optflags -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
export CXXFLAGS="$CXXFLAGS -std=gnu++11"
autoreconf -fiv
%configure \
	--with-xmlrpc-c="%_bindir/xmlrpc-c-config" \
	--enable-ipv6
%make_build

%install
b="%buildroot"
%make_install
install -Dm0644 "%{S:2}" "$b/%_datadir/applications/%name.desktop"
mkdir -p "$b/%_mandir/man1"
install -pm0644 "%{S:3}" "$b/%_mandir/man1/"
%suse_update_desktop_file -r "%name" Network P2P
install -Dm0644 "%{S:4}" "$b/%_unitdir/rtorrent.service"

%pre
getent passwd rtorrent >/dev/null || useradd -r rtorrent
%service_add_pre rtorrent.service

%post
%service_add_post rtorrent.service

%preun
%service_del_preun rtorrent.service

%postun
%service_del_postun rtorrent.service

%files
%doc doc/rtorrent.rc
%license COPYING
%_bindir/rtorrent
%_datadir/applications/%name.desktop
%_mandir/man1/rtorrent.1*
%_unitdir/rtorrent.service

%changelog
* Tue Jun 21 2022 Aleksa Sarai <asarai@suse.com>
- Backport fix which resolves a crashing issue on startup on openSUSE.
  https://github.com/rakshasa/rtorrent/pull/1169
  + 0001-utils-lockfile-avoid-stack-overflow-for-lockfile-buf.patch
* Tue Nov 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * rtorrent.service
* Fri Sep  4 2020 Jan Engelhardt <jengelh@inai.de>
- Drop old specfile constructs.
* Fri Jan 24 2020 Jan Engelhardt <jengelh@inai.de>
- Add missing require on useradd.
* Fri Aug 16 2019 Jan Engelhardt <jengelh@inai.de>
- Add missing %%service_* scriptlets
* Wed Jul 24 2019 hiwatari.seiji@gmail.com
- Update to 0.9.8
  * Close log files when reusing a name. (pyroscope)
  * Increased max timeout for tracker requests.
  * Set max piece size 512mb.
  * Switch to C++11 MRT RNG for random bytes. (lps-rocks)
  * Added support for openssl 1.1.
  * Fix honoring throttle.min_peers* settings in rtorrent. (chros)
  * Improved failed tracker bencode parsing. (chros)
  * Added example rtorrent.rc. (g0tmi1k)
  * Added a temporary name filter. (Toff)
  * Added 'log.close' command.
  * Added 'd.tracker_announce.force' command.
  * Added 'event.system.startup_done/shutdown' commands/events. (chros)
  * Added 'd.custom.if_z' command. (pyroscope)
  * Added 'd.multicall.filtered' command. (pyroscope)
  * Added 'event.view.hide/show' commands. (pyroscope)
- Update to 0.9.7
  * Fixed ip filter memory usage. (sallyswiss/chros73)
  * Add space to fmt str in log_gz_file_write. (pastly)
  * Fix compilation issue with gcc v6.x and empty CXXFLAGS. (chros73)
  * Fix BEP7 compatibility with IPv6 trackers and IPv4 peers.
  * Include SCGI/XMLRPC example in rtorrent.rc. (ss23)
  * Handle SIGHUP like SIGINT. (pyroscope)
  * Fix Throttle args. (chros73)
  * Fix missing ranlib - not defined but used. (duraki)
  * Fix no // are at start of expanded paths. (pyroscope)
  * Fix ncurses header include. (theirix)
  * Fix segfault when viewing a magnet download in the leeching view. (slingamn)
- Remove rtorrent-vim package because it was made for the old (now discouraged) config syntax
  * See: https://github.com/rakshasa/rtorrent/wiki/CONFIG-Template
* Mon Dec 11 2017 jengelh@inai.de
- Update to new snapshot 0.9.6.g113
  * Support for new libtorrent API regarding logging file
    descriptors and IPv6 binds.
* Tue Jun  6 2017 jengelh@inai.de
- Update to new snapshot 0.9.6.g93
  * IPv6 support
  * add support for the XDG base dir spec for rtorrent.rc
  * daemonization support
  * maximum supported filesize now 512 GB
- Change from requiring libxmlrpc-c-devel to xmlrpc-c-devel
  [boo#1042228]
* Sun Nov 15 2015 mpluskal@suse.com
- Enable xmlrpc on Tumbleweed
* Fri Nov 13 2015 tampakrap@opensuse.org
- Update to new upstream release 0.9.6
  * Added 'log.open_file_pid' and 'log.open_gz_file_pid' commands
  that appends the pid automatically.
- Moved fully to github, change URL and Source accordingly
* Tue Aug  5 2014 jengelh@inai.de
- It is supposed to be packageand(vim:rtorrent)
* Sun Aug  3 2014 tampakrap@opensuse.org
- Add Supplements: packageand(vim,rtorrent), in order to trigger automatic
  installation for users of both packages. Suggested by dimstar
* Sun Jul 27 2014 tampakrap@opensuse.org
- Add vim as BuildRequirement and Requirement for rtorrent-vim, so that it
  doesn't own vim's directories
* Sat Jul 19 2014 tampakrap@opensuse.org
- Vim syntax file for rTorrent's config file, .rtorrent.rc
  The files are taken from http://www.vim.org/scripts/script.php?script_id=2234
* Sat Jul 19 2014 jengelh@inai.de
- Update to new upstream release 0.9.4
  * Added unordered curve to plot
  * Added 'network.listen.backlog{,.set}' commands
  * Added 'log.open_gz_file' option
* Fri Feb  8 2013 jengelh@inai.de
- Initial package (version 0.9.3) for OpenSUSE
